
.. xoutil documentation master file, created by
   sphinx-quickstart on Fri Jun 15 14:31:00 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to xoutil's documentation!
==================================

.. automodule:: xoutil

What's new in |release|
-----------------------

.. include:: history/_changes-1.7.12.rst


Contents:
---------

.. toctree::
   :maxdepth: 2
   :glob:

   xoutil/toplevel
   xoutil/*
   others
   HISTORY
   BACKLOG
   CONTRIBUTING
   CONTRIBUTORS
   LICENSE


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
